#!/bin/bash -e

REL_TYPE="$1"
SCRIPTS_DIR=$(cd "$(dirname "$0")" && pwd) || exit
PROJECT_HOME="$SCRIPTS_DIR/.."
FILES_DIR="$PROJECT_HOME/container/$REL_TYPE"
APP_DIR="$PROJECT_HOME/app"
APP_NAME=$(cd $APP_DIR && yq -r '.name' pubspec.yaml)
IMAGE_NAME="${APP_NAME}_${REL_TYPE//release/rel}_image"
IMAGE_TAG="latest"
IMAGE_ARCHIVE_FILE="$FILES_DIR/${IMAGE_NAME}.tar"

source "$SCRIPTS_DIR"/util.sh
"$SCRIPTS_DIR"/build_base_container_image.sh

(
    cd "$FILES_DIR"
    if ! podman image inspect "localhost/$IMAGE_NAME":"$IMAGE_TAG" >& /dev/null; then
        podman build -t "localhost/$IMAGE_NAME":"$IMAGE_TAG" .
    else
        if prompt_yesno n "%s already exists, rebuild? [y/N]" "$IMAGE_NAME"; then
            podman rmi "localhost/$IMAGE_NAME":"$IMAGE_TAG"
            podman build -t "$IMAGE_NAME":"$IMAGE_TAG" .
        fi
    fi
)

rm -rf "$IMAGE_ARCHIVE_FILE"
podman save -o "$IMAGE_ARCHIVE_FILE" "localhost/$IMAGE_NAME":"$IMAGE_TAG"
