#!/bin/bash -e

SCRIPTS_DIR=$(cd "$(dirname "$0")" && pwd) || exit
PROJECT_HOME="$SCRIPTS_DIR/.."
DEV_FILES_DIR="$PROJECT_HOME/container/dev"
RESOURCES_DIR="$DEV_FILES_DIR/resources"
APP_DIR="$PROJECT_HOME/app"
APP_NAME=$(cd $APP_DIR && yq -r '.name' pubspec.yaml)
IMAGE_NAME="${APP_NAME}_dev_image"
IMAGE_TAG="latest"
DESC_FILE="$DEV_FILES_DIR/${IMAGE_NAME}.desc"
SSH_DIR="$PROJECT_HOME/config/ssh"
TEMPLATE_DIR="$DEV_FILES_DIR/template"
CONF_TEMPLATE_FILE="container.conf.tmpl"
ROOT_CONF_DIR="$DEV_FILES_DIR/root/etc/atmark/containers"

gen_swu() {
    version=1

    if [ -e "$DESC_FILE" ]; then
        version=$(awk -F= '$1 == "swdesc_option version" { print $2 + 1 }' "$DESC_FILE")
        mv -f "$DESC_FILE" "$DESC_FILE".old
    fi
    cat > "$DESC_FILE" <<EODESC
swdesc_option version=${version:-1}

swdesc_files --extra-os root
swdesc_embed_container "${IMAGE_NAME}.tar"
EODESC

mkswu "$DESC_FILE"
}


if [[ ! -e "$SSH_DIR/id_rsa.pub" ]]; then
    echo "id_rsa.pub not found." >&2
    echo "Please do [Terminal]->[Run Tasks...]->[Setup envronment] first on the VSCode menu." >&2
    exit 1
fi

cat "$SSH_DIR/id_rsa.pub" > "$RESOURCES_DIR/root/.ssh/authorized_keys"

sed -e "s/{{IMAGE_NAME}}/$IMAGE_NAME/g" -e "s/{{IMAGE_TAG}}/$IMAGE_TAG/g" -e "s/{{APP_NAME}}/$APP_NAME/g" \
    "$TEMPLATE_DIR"/"$CONF_TEMPLATE_FILE" > "$ROOT_CONF_DIR"/"$APP_NAME".conf

"$SCRIPTS_DIR"/build_container_image.sh dev

gen_swu
